Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Response ¶
type Response struct {
// Basic metadata
HTTPStatusCode int `json:"code"`
RequestID string `json:"request_id,omitempty"`
// Message is included in all responses, and is a summary of the server's response
Message string `json:"message"`
// Err contains additional context in the event of an error
Err string `json:"error,omitempty"`
// Data contains information the server wants to return
Data interface{} `json:"data,omitempty"`
}
Response is the underlying response structure to all responses.
func NewResponse ¶
NewResponse creates an instance of the standard basic response renderer
Click to show internal directories.
Click to hide internal directories.